==> zio-aws-ec2_2.12-5.17.145.1-sources.jar: zio/aws/ec2/model/GetConsoleOutputRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.InstanceId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetConsoleOutputRequest(
    instanceId: InstanceId,
    latest: Option[Boolean] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.GetConsoleOutputRequest = {
    import GetConsoleOutputRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.GetConsoleOutputRequest
      .builder()
      .instanceId(InstanceId.unwrap(instanceId): java.lang.String)
      .optionallyWith(latest.map(value => value: java.lang.Boolean))(_.latest)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.GetConsoleOutputRequest.ReadOnly =
    zio.aws.ec2.model.GetConsoleOutputRequest.wrap(buildAwsValue())
}
object GetConsoleOutputRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.GetConsoleOutputRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.GetConsoleOutputRequest =
      zio.aws.ec2.model
        .GetConsoleOutputRequest(instanceId, latest.map(value => value))
    def instanceId: InstanceId
    def latest: Option[Boolean]
    def getInstanceId: ZIO[Any, Nothing, InstanceId] = ZIO.succeed(instanceId)
    def getLatest: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("latest", latest)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.GetConsoleOutputRequest
  ) extends zio.aws.ec2.model.GetConsoleOutputRequest.ReadOnly {
    override val instanceId: InstanceId =
      zio.aws.ec2.model.primitives.InstanceId(impl.instanceId())
    override val latest: Option[Boolean] =
      scala.Option(impl.latest()).map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.GetConsoleOutputRequest
  ): zio.aws.ec2.model.GetConsoleOutputRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.12-7.21.15.7-sources.jar: zio/aws/ec2/model/GetConsoleOutputRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.InstanceId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetConsoleOutputRequest(
    instanceId: InstanceId,
    dryRun: Optional[Boolean] = Optional.Absent,
    latest: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.GetConsoleOutputRequest = {
    import GetConsoleOutputRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.GetConsoleOutputRequest
      .builder()
      .instanceId(InstanceId.unwrap(instanceId): java.lang.String)
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .optionallyWith(latest.map(value => value: java.lang.Boolean))(_.latest)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.GetConsoleOutputRequest.ReadOnly =
    zio.aws.ec2.model.GetConsoleOutputRequest.wrap(buildAwsValue())
}
object GetConsoleOutputRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.GetConsoleOutputRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.GetConsoleOutputRequest =
      zio.aws.ec2.model.GetConsoleOutputRequest(
        instanceId,
        dryRun.map(value => value),
        latest.map(value => value)
      )
    def instanceId: InstanceId
    def dryRun: Optional[Boolean]
    def latest: Optional[Boolean]
    def getInstanceId: ZIO[Any, Nothing, InstanceId] = ZIO.succeed(instanceId)
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
    def getLatest: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("latest", latest)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.GetConsoleOutputRequest
  ) extends zio.aws.ec2.model.GetConsoleOutputRequest.ReadOnly {
    override val instanceId: InstanceId =
      zio.aws.ec2.model.primitives.InstanceId(impl.instanceId())
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
    override val latest: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.latest())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.GetConsoleOutputRequest
  ): zio.aws.ec2.model.GetConsoleOutputRequest.ReadOnly = new Wrapper(impl)
}
